==> synapseml-0.9.5-py2.py3-none-any.whl: synapse/ml/geospatial/CheckPointInPolygon.py <==
# Copyright (C) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE in project root for information.


import sys
if sys.version >= '3':
    basestring = str

from pyspark import SparkContext, SQLContext
from pyspark.sql import DataFrame
from pyspark.ml.param.shared import *
from pyspark import keyword_only
from pyspark.ml.util import JavaMLReadable, JavaMLWritable
from synapse.ml.core.serialize.java_params_patch import *
from pyspark.ml.wrapper import JavaTransformer, JavaEstimator, JavaModel
from pyspark.ml.evaluation import JavaEvaluator
from pyspark.ml.common import inherit_doc
from synapse.ml.core.schema.Utils import *
from pyspark.ml.param import TypeConverters
from synapse.ml.core.schema.TypeConversionUtils import generateTypeConverter, complexTypeConverter


@inherit_doc
class CheckPointInPolygon(ComplexParamsMixin, JavaMLReadable, JavaMLWritable, JavaTransformer):
    """
    Args:
        concurrency (int): max number of concurrent calls
        concurrentTimeout (float): max number seconds to wait on futures if concurrency >= 1
        errorCol (object): column to hold http errors
        handler (object): Which strategy to use when handling requests
        latitude (object): the latitude of location
        longitude (object): the longitude of location
        outputCol (object): The name of the output column
        subscriptionKey (object): the API key to use
        timeout (float): number of seconds to wait before closing the connection
        url (object): Url of the service
        userDataIdentifier (object): the identifier for the user uploaded data
    """

    concurrency = Param(Params._dummy(), "concurrency", "max number of concurrent calls", typeConverter=TypeConverters.toInt)
    
    concurrentTimeout = Param(Params._dummy(), "concurrentTimeout", "max number seconds to wait on futures if concurrency >= 1", typeConverter=TypeConverters.toFloat)
    
    errorCol = Param(Params._dummy(), "errorCol", "column to hold http errors")
    
    handler = Param(Params._dummy(), "handler", "Which strategy to use when handling requests")
    
    latitude = Param(Params._dummy(), "latitude", "the latitude of location")
    
    longitude = Param(Params._dummy(), "longitude", "the longitude of location")
    
    outputCol = Param(Params._dummy(), "outputCol", "The name of the output column")
    
    subscriptionKey = Param(Params._dummy(), "subscriptionKey", "the API key to use")
    
    timeout = Param(Params._dummy(), "timeout", "number of seconds to wait before closing the connection", typeConverter=TypeConverters.toFloat)
    
    url = Param(Params._dummy(), "url", "Url of the service")
    
    userDataIdentifier = Param(Params._dummy(), "userDataIdentifier", "the identifier for the user uploaded data")

    
    @keyword_only
    def __init__(
        self,
        java_obj=None,
        concurrency=1,
        concurrentTimeout=None,
        errorCol="CheckPointInPolygon_4f8abcef55d7_error",
        handler=None,
        latitude=None,
        latitudeCol=None,
        longitude=None,
        longitudeCol=None,
        outputCol="CheckPointInPolygon_4f8abcef55d7_output",
        subscriptionKey=None,
        subscriptionKeyCol=None,
        timeout=60.0,
        url="https://atlas.microsoft.com/",
        userDataIdentifier=None,
        userDataIdentifierCol=None
        ):
        super(CheckPointInPolygon, self).__init__()
        if java_obj is None:
            self._java_obj = self._new_java_obj("com.microsoft.azure.synapse.ml.geospatial.CheckPointInPolygon", self.uid)
        else:
            self._java_obj = java_obj
        self._setDefault(concurrency=1)
        self._setDefault(errorCol="CheckPointInPolygon_4f8abcef55d7_error")
        self._setDefault(outputCol="CheckPointInPolygon_4f8abcef55d7_output")
        self._setDefault(timeout=60.0)
        self._setDefault(url="https://atlas.microsoft.com/")
        if hasattr(self, "_input_kwargs"):
            kwargs = self._input_kwargs
        else:
            kwargs = self.__init__._input_kwargs
    
        if java_obj is None:
            for k,v in kwargs.items():
                if v is not None:
                    getattr(self, "set" + k[0].upper() + k[1:])(v)

    @keyword_only
    def setParams(
        self,
        concurrency=1,
        concurrentTimeout=None,
        errorCol="CheckPointInPolygon_4f8abcef55d7_error",
        handler=None,
        latitude=None,
        latitudeCol=None,
        longitude=None,
        longitudeCol=None,
        outputCol="CheckPointInPolygon_4f8abcef55d7_output",
        subscriptionKey=None,
        subscriptionKeyCol=None,
        timeout=60.0,
        url="https://atlas.microsoft.com/",
        userDataIdentifier=None,
        userDataIdentifierCol=None
        ):
        """
        Set the (keyword only) parameters
        """
        if hasattr(self, "_input_kwargs"):
            kwargs = self._input_kwargs
        else:
            kwargs = self.__init__._input_kwargs
        return self._set(**kwargs)

    @classmethod
    def read(cls):
        """ Returns an MLReader instance for this class. """
        return JavaMMLReader(cls)

    @staticmethod
    def getJavaPackage():
        """ Returns package name String. """
        return "com.microsoft.azure.synapse.ml.geospatial.CheckPointInPolygon"

    @staticmethod
    def _from_java(java_stage):
        module_name=CheckPointInPolygon.__module__
        module_name=module_name.rsplit(".", 1)[0] + ".CheckPointInPolygon"
        return from_java(java_stage, module_name)

    def setConcurrency(self, value):
        """
        Args:
            concurrency: max number of concurrent calls
        """
        self._set(concurrency=value)
        return self
    
    def setConcurrentTimeout(self, value):
        """
        Args:
            concurrentTimeout: max number seconds to wait on futures if concurrency >= 1
        """
        self._set(concurrentTimeout=value)
        return self
    
    def setErrorCol(self, value):
        """
        Args:
            errorCol: column to hold http errors
        """
        self._set(errorCol=value)
        return self
    
    def setHandler(self, value):
        """
        Args:
            handler: Which strategy to use when handling requests
        """
        self._set(handler=value)
        return self
    
    def setLatitude(self, value):
        """
        Args:
            latitude: the latitude of location
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.org.apache.spark.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setLatitude(value)
        return self
    
    def setLatitudeCol(self, value):
        """
        Args:
            latitude: the latitude of location
        """
        self._java_obj = self._java_obj.setLatitudeCol(value)
        return self
    
    def setLongitude(self, value):
        """
        Args:
            longitude: the longitude of location
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.org.apache.spark.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setLongitude(value)
        return self
    
    def setLongitudeCol(self, value):
        """
        Args:
            longitude: the longitude of location
        """
        self._java_obj = self._java_obj.setLongitudeCol(value)
        return self
    
    def setOutputCol(self, value):
        """
        Args:
            outputCol: The name of the output column
        """
        self._set(outputCol=value)
        return self
    
    def setSubscriptionKey(self, value):
        """
        Args:
            subscriptionKey: the API key to use
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.org.apache.spark.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setSubscriptionKey(value)
        return self
    
    def setSubscriptionKeyCol(self, value):
        """
        Args:
            subscriptionKey: the API key to use
        """
        self._java_obj = self._java_obj.setSubscriptionKeyCol(value)
        return self
    
    def setTimeout(self, value):
        """
        Args:
            timeout: number of seconds to wait before closing the connection
        """
        self._set(timeout=value)
        return self
    
    def setUrl(self, value):
        """
        Args:
            url: Url of the service
        """
        self._set(url=value)
        return self
    
    def setUserDataIdentifier(self, value):
        """
        Args:
            userDataIdentifier: the identifier for the user uploaded data
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.org.apache.spark.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setUserDataIdentifier(value)
        return self
    
    def setUserDataIdentifierCol(self, value):
        """
        Args:
            userDataIdentifier: the identifier for the user uploaded data
        """
        self._java_obj = self._java_obj.setUserDataIdentifierCol(value)
        return self

    
    def getConcurrency(self):
        """
        Returns:
            concurrency: max number of concurrent calls
        """
        return self.getOrDefault(self.concurrency)
    
    
    def getConcurrentTimeout(self):
        """
        Returns:
            concurrentTimeout: max number seconds to wait on futures if concurrency >= 1
        """
        return self.getOrDefault(self.concurrentTimeout)
    
    
    def getErrorCol(self):
        """
        Returns:
            errorCol: column to hold http errors
        """
        return self.getOrDefault(self.errorCol)
    
    
    def getHandler(self):
        """
        Returns:
            handler: Which strategy to use when handling requests
        """
        return self.getOrDefault(self.handler)
    
    
    def getLatitude(self):
        """
        Returns:
            latitude: the latitude of location
        """
        return self.getOrDefault(self.latitude)
    
    
    def getLongitude(self):
        """
        Returns:
            longitude: the longitude of location
        """
        return self.getOrDefault(self.longitude)
    
    
    def getOutputCol(self):
        """
        Returns:
            outputCol: The name of the output column
        """
        return self.getOrDefault(self.outputCol)
    
    
    def getSubscriptionKey(self):
        """
        Returns:
            subscriptionKey: the API key to use
        """
        return self.getOrDefault(self.subscriptionKey)
    
    
    def getTimeout(self):
        """
        Returns:
            timeout: number of seconds to wait before closing the connection
        """
        return self.getOrDefault(self.timeout)
    
    
    def getUrl(self):
        """
        Returns:
            url: Url of the service
        """
        return self.getOrDefault(self.url)
    
    
    def getUserDataIdentifier(self):
        """
        Returns:
            userDataIdentifier: the identifier for the user uploaded data
        """
        return self.getOrDefault(self.userDataIdentifier)

    

    
    def setGeography(self, value):
        self._java_obj = self._java_obj.setGeography(value)
        return self

==> synapseml-0.10.0-py2.py3-none-any.whl: synapse/ml/geospatial/CheckPointInPolygon.py <==
# Copyright (C) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE in project root for information.


import sys
if sys.version >= '3':
    basestring = str

from pyspark import SparkContext, SQLContext
from pyspark.sql import DataFrame
from pyspark.ml.param.shared import *
from pyspark import keyword_only
from pyspark.ml.util import JavaMLReadable, JavaMLWritable
from synapse.ml.core.serialize.java_params_patch import *
from pyspark.ml.wrapper import JavaTransformer, JavaEstimator, JavaModel
from pyspark.ml.evaluation import JavaEvaluator
from pyspark.ml.common import inherit_doc
from synapse.ml.core.schema.Utils import *
from pyspark.ml.param import TypeConverters
from synapse.ml.core.schema.TypeConversionUtils import generateTypeConverter, complexTypeConverter


@inherit_doc
class CheckPointInPolygon(ComplexParamsMixin, JavaMLReadable, JavaMLWritable, JavaTransformer):
    """
    Args:
        concurrency (int): max number of concurrent calls
        concurrentTimeout (float): max number seconds to wait on futures if concurrency >= 1
        errorCol (str): column to hold http errors
        handler (object): Which strategy to use when handling requests
        latitude (object): the latitude of location
        longitude (object): the longitude of location
        outputCol (str): The name of the output column
        subscriptionKey (object): the API key to use
        timeout (float): number of seconds to wait before closing the connection
        url (str): Url of the service
        userDataIdentifier (object): the identifier for the user uploaded data
    """

    concurrency = Param(Params._dummy(), "concurrency", "max number of concurrent calls", typeConverter=TypeConverters.toInt)
    
    concurrentTimeout = Param(Params._dummy(), "concurrentTimeout", "max number seconds to wait on futures if concurrency >= 1", typeConverter=TypeConverters.toFloat)
    
    errorCol = Param(Params._dummy(), "errorCol", "column to hold http errors", typeConverter=TypeConverters.toString)
    
    handler = Param(Params._dummy(), "handler", "Which strategy to use when handling requests")
    
    latitude = Param(Params._dummy(), "latitude", "ServiceParam: the latitude of location")
    
    longitude = Param(Params._dummy(), "longitude", "ServiceParam: the longitude of location")
    
    outputCol = Param(Params._dummy(), "outputCol", "The name of the output column", typeConverter=TypeConverters.toString)
    
    subscriptionKey = Param(Params._dummy(), "subscriptionKey", "ServiceParam: the API key to use")
    
    timeout = Param(Params._dummy(), "timeout", "number of seconds to wait before closing the connection", typeConverter=TypeConverters.toFloat)
    
    url = Param(Params._dummy(), "url", "Url of the service", typeConverter=TypeConverters.toString)
    
    userDataIdentifier = Param(Params._dummy(), "userDataIdentifier", "ServiceParam: the identifier for the user uploaded data")

    
    @keyword_only
    def __init__(
        self,
        java_obj=None,
        concurrency=1,
        concurrentTimeout=None,
        errorCol="CheckPointInPolygon_bf1272f621f8_error",
        handler=None,
        latitude=None,
        latitudeCol=None,
        longitude=None,
        longitudeCol=None,
        outputCol="CheckPointInPolygon_bf1272f621f8_output",
        subscriptionKey=None,
        subscriptionKeyCol=None,
        timeout=60.0,
        url="https://atlas.microsoft.com/",
        userDataIdentifier=None,
        userDataIdentifierCol=None
        ):
        super(CheckPointInPolygon, self).__init__()
        if java_obj is None:
            self._java_obj = self._new_java_obj("com.microsoft.azure.synapse.ml.geospatial.CheckPointInPolygon", self.uid)
        else:
            self._java_obj = java_obj
        self._setDefault(concurrency=1)
        self._setDefault(errorCol="CheckPointInPolygon_bf1272f621f8_error")
        self._setDefault(outputCol="CheckPointInPolygon_bf1272f621f8_output")
        self._setDefault(timeout=60.0)
        self._setDefault(url="https://atlas.microsoft.com/")
        if hasattr(self, "_input_kwargs"):
            kwargs = self._input_kwargs
        else:
            kwargs = self.__init__._input_kwargs
    
        if java_obj is None:
            for k,v in kwargs.items():
                if v is not None:
                    getattr(self, "set" + k[0].upper() + k[1:])(v)

    @keyword_only
    def setParams(
        self,
        concurrency=1,
        concurrentTimeout=None,
        errorCol="CheckPointInPolygon_bf1272f621f8_error",
        handler=None,
        latitude=None,
        latitudeCol=None,
        longitude=None,
        longitudeCol=None,
        outputCol="CheckPointInPolygon_bf1272f621f8_output",
        subscriptionKey=None,
        subscriptionKeyCol=None,
        timeout=60.0,
        url="https://atlas.microsoft.com/",
        userDataIdentifier=None,
        userDataIdentifierCol=None
        ):
        """
        Set the (keyword only) parameters
        """
        if hasattr(self, "_input_kwargs"):
            kwargs = self._input_kwargs
        else:
            kwargs = self.__init__._input_kwargs
        return self._set(**kwargs)

    @classmethod
    def read(cls):
        """ Returns an MLReader instance for this class. """
        return JavaMMLReader(cls)

    @staticmethod
    def getJavaPackage():
        """ Returns package name String. """
        return "com.microsoft.azure.synapse.ml.geospatial.CheckPointInPolygon"

    @staticmethod
    def _from_java(java_stage):
        module_name=CheckPointInPolygon.__module__
        module_name=module_name.rsplit(".", 1)[0] + ".CheckPointInPolygon"
        return from_java(java_stage, module_name)

    def setConcurrency(self, value):
        """
        Args:
            concurrency: max number of concurrent calls
        """
        self._set(concurrency=value)
        return self
    
    def setConcurrentTimeout(self, value):
        """
        Args:
            concurrentTimeout: max number seconds to wait on futures if concurrency >= 1
        """
        self._set(concurrentTimeout=value)
        return self
    
    def setErrorCol(self, value):
        """
        Args:
            errorCol: column to hold http errors
        """
        self._set(errorCol=value)
        return self
    
    def setHandler(self, value):
        """
        Args:
            handler: Which strategy to use when handling requests
        """
        self._set(handler=value)
        return self
    
    def setLatitude(self, value):
        """
        Args:
            latitude: the latitude of location
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.com.microsoft.azure.synapse.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setLatitude(value)
        return self
    
    def setLatitudeCol(self, value):
        """
        Args:
            latitude: the latitude of location
        """
        self._java_obj = self._java_obj.setLatitudeCol(value)
        return self
    
    def setLongitude(self, value):
        """
        Args:
            longitude: the longitude of location
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.com.microsoft.azure.synapse.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setLongitude(value)
        return self
    
    def setLongitudeCol(self, value):
        """
        Args:
            longitude: the longitude of location
        """
        self._java_obj = self._java_obj.setLongitudeCol(value)
        return self
    
    def setOutputCol(self, value):
        """
        Args:
            outputCol: The name of the output column
        """
        self._set(outputCol=value)
        return self
    
    def setSubscriptionKey(self, value):
        """
        Args:
            subscriptionKey: the API key to use
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.com.microsoft.azure.synapse.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setSubscriptionKey(value)
        return self
    
    def setSubscriptionKeyCol(self, value):
        """
        Args:
            subscriptionKey: the API key to use
        """
        self._java_obj = self._java_obj.setSubscriptionKeyCol(value)
        return self
    
    def setTimeout(self, value):
        """
        Args:
            timeout: number of seconds to wait before closing the connection
        """
        self._set(timeout=value)
        return self
    
    def setUrl(self, value):
        """
        Args:
            url: Url of the service
        """
        self._set(url=value)
        return self
    
    def setUserDataIdentifier(self, value):
        """
        Args:
            userDataIdentifier: the identifier for the user uploaded data
        """
        if isinstance(value, list):
            value = SparkContext._active_spark_context._jvm.com.microsoft.azure.synapse.ml.param.ServiceParam.toSeq(value)
        self._java_obj = self._java_obj.setUserDataIdentifier(value)
        return self
    
    def setUserDataIdentifierCol(self, value):
        """
        Args:
            userDataIdentifier: the identifier for the user uploaded data
        """
        self._java_obj = self._java_obj.setUserDataIdentifierCol(value)
        return self

    
    def getConcurrency(self):
        """
        Returns:
            concurrency: max number of concurrent calls
        """
        return self.getOrDefault(self.concurrency)
    
    
    def getConcurrentTimeout(self):
        """
        Returns:
            concurrentTimeout: max number seconds to wait on futures if concurrency >= 1
        """
        return self.getOrDefault(self.concurrentTimeout)
    
    
    def getErrorCol(self):
        """
        Returns:
            errorCol: column to hold http errors
        """
        return self.getOrDefault(self.errorCol)
    
    
    def getHandler(self):
        """
        Returns:
            handler: Which strategy to use when handling requests
        """
        return self.getOrDefault(self.handler)
    
    
    def getLatitude(self):
        """
        Returns:
            latitude: the latitude of location
        """
        return self._java_obj.getLatitude()
    
    
    def getLongitude(self):
        """
        Returns:
            longitude: the longitude of location
        """
        return self._java_obj.getLongitude()
    
    
    def getOutputCol(self):
        """
        Returns:
            outputCol: The name of the output column
        """
        return self.getOrDefault(self.outputCol)
    
    
    def getSubscriptionKey(self):
        """
        Returns:
            subscriptionKey: the API key to use
        """
        return self._java_obj.getSubscriptionKey()
    
    
    def getTimeout(self):
        """
        Returns:
            timeout: number of seconds to wait before closing the connection
        """
        return self.getOrDefault(self.timeout)
    
    
    def getUrl(self):
        """
        Returns:
            url: Url of the service
        """
        return self.getOrDefault(self.url)
    
    
    def getUserDataIdentifier(self):
        """
        Returns:
            userDataIdentifier: the identifier for the user uploaded data
        """
        return self._java_obj.getUserDataIdentifier()

    

    
    def setGeography(self, value):
        self._java_obj = self._java_obj.setGeography(value)
        return self
